pub struct MarketTransaction {
pub id: MarketTransactionId,
pub date: OffsetDateTime,
pub status: TransactionStatus,
pub server_id: Option<ServerId>,
pub authorized_keys: Vec<InitialProductSshKey>,
pub host_keys: Vec<HostKey>,
pub comment: Option<String>,
pub product: PurchasedMarketProduct,
}Expand description
Describes the purchase of a single Hetzner market (auction) server.
Fields
id: MarketTransactionIdUnique transaction ID.
date: OffsetDateTimeTimestamp for the purchase.
status: TransactionStatusStatus of the transaction.
server_id: Option<ServerId>Server ID of the purchased server.
Keys authorized to access the rescue system via SSH.
host_keys: Vec<HostKey>Host keys associated with the product.
comment: Option<String>Optional comment associated with the purchase.
product: PurchasedMarketProductSummary of the purchased product configuration.